[![Version](https://img.shields.io/badge/VERSION-1.1.1-brightgreen)]()
[![License](https://img.shields.io/badge/license-GPL-blue.svg?style=flat)](https://github.com/miguel93041/accessmysqlconverter/blob/master/LICENSE)
[![paypal](https://www.paypalobjects.com/en_US/ES/i/btn/btn_donateCC_LG.gif)](https://www.paypal.com/donate?hosted_button_id=N8EGU933CPFV8)

# AccessMySQLConverter
AccessMySQLConverter aims to provide a tool which converts MS Access database files (.mdb, .accdb) into a SQL file (and viceversa in future releases) that can be run, generating It's structure and optionally importing It's data

## Installation
To install it you must have Python 3.x installed and run in the command prompt

**pip install --no-cache-dir --upgrade accessmysqlconverter**

## Run it
For executing the program run in the command prompt the following instruction

**python -m accessmysqlconverter.application**

## License
See [LICENSE](LICENSE.gpl) for more information

## Donations
[![paypal](https://www.paypalobjects.com/en_US/ES/i/btn/btn_donateCC_LG.gif)](https://www.paypal.com/donate?hosted_button_id=N8EGU933CPFV8)